import json
import os
from dataclasses import dataclass
from logging import getLogger
from pathlib import Path


@dataclass
class Config:
    HOST: str = "localhost"
    PORT: int = 8000
    LOG_LEVEL: str = "DEBUG"
    ACCESS_LOGGING: bool = True
    JINJA_TEMPLATE_PATH: str = "."


def config_init() -> Config:
    logger = getLogger("Tonberry")
    env_var_name = "TONBERRY_CONFIG"
    path_str = os.environ.get(env_var_name)
    config_path = Path(path_str or "")
    if not config_path.is_file():
        logger.warning(
            f"Config file path is not valid or not set, loading default values. To use "
            f"a config file set up an environment variable called '{env_var_name}' and "
            f"set the value to a JSON config file path."
        )
        return Config()
    return Config(**json.loads(config_path.open().read()))



from setuptools import find_packages, setup

with open('CHANGELOG.md', 'r') as fh:
    for line in fh.readlines():
        if 'Current Version: ' in line:
            version = line.replace('Current Version: ', '')
            break

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt", "r") as fh:
    requirements = fh.readlines()

setup(
    name="Tonberry",
    version=version,
    description="ASGI compliant web microframework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Anthony Post",
    author_email="postanthony3000@gmail.com",
    license="MIT License",
    url="https://github.com/Ayehavgunne/Tonberry/",
    packages=find_packages(),
    install_requires=requirements,
    extras_require={"dev": ["mypy", "black", "isort"]},
    python_requires=">=3.7",
)
